@@ -3,7 +3,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2026	PgPool Global Development Group
+ * Copyright (c) 2003-2025	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -21,6 +21,7 @@
 */
 
 #include "pool.h"
+#include <unistd.h>
 #include "context/pool_session_context.h"
 #include "protocol/pool_process_query.h"
 #include "protocol/pool_proto_modules.h"
@@ -34,6 +35,7 @@
 #include "utils/palloc.h"
 #include "utils/memutils.h"
 #include "auth/md5.h"
+#include <unistd.h>
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -151,6 +153,29 @@ connection_do_auth(POOL_CONNECTION_POOL_SLOT * cp, char *password)
 
 		cp->con->auth_kind = AUTH_REQ_OK;
 	}
+	else if (auth_kind == AUTH_REQ_CRYPT)	/* crypt password? */
+	{
+		char		salt[3];
+		char	   *crypt_password;
+
+		pool_read_with_error(cp->con, &salt, 2, "crypt salt");
+		salt[2] = '\0';
+
+		crypt_password = crypt(password, salt);
+		if (crypt_password == NULL)
+			ereport(ERROR,
+					(errmsg("crypt authentication failed for user:%s", cp->sp->user),
+					 errdetail("failed to encrypt the password")));
+
+		/* Send password packet to backend and receive auth response */
+		kind = send_password_packet(cp->con, PROTO_MAJOR_V3, crypt_password);
+		if (kind != AUTH_REQ_OK)
+			ereport(ERROR,
+					(errmsg("crypt authentication failed for user:%s", cp->sp->user),
+					 errdetail("backend replied with invalid kind")));
+
+		cp->con->auth_kind = AUTH_REQ_OK;
+	}
 	else if (auth_kind == AUTH_REQ_MD5) /* md5 password? */
 	{
 		char		salt[4];
@@ -1042,7 +1067,7 @@ do_clear_text_password(POOL_CONNECTION * backend, POOL_CONNECTION * frontend, in
 		if (size != backend->pwd_size)
 			ereport(ERROR,
 					(errmsg("clear text password authentication failed"),
-					 errdetail("password does not match")));
+					 errdetail("password size does not match")));
 
 		if (memcmp(pwd, backend->password, backend->pwd_size) != 0)
 			ereport(ERROR,
@@ -1894,8 +1919,6 @@ do_SCRAM(POOL_CONNECTION * frontend, POOL_CONNECTION * backend, int protoMajor,
 				 * The request contains the name (as assigned by IANA) of the
 				 * authentication mechanism.
 				 */
-				if (sasl_state)
-					pg_fe_scram_free(sasl_state);
 				sasl_state = pg_SASL_init(backend, payload, payload_len, username, storedPassword);
 				if (!sasl_state)
 				{
